#
# RPM spec file for php-doctrine-datafixtures
#
# Copyright (c) 2013-2014 Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     doctrine
%global github_name      data-fixtures
%global github_version   1.0.0
%global github_commit    b4a135c7db56ecc4602b54a2184368f440cac33e

%global composer_vendor  doctrine
%global composer_project data-fixtures

# "php": ">=5.3.2"
%global php_min_ver      5.3.2
# "doctrine/*": ">=2.2,<2.5-dev"
%global doctrine_min_ver 2.2
%global doctrine_max_ver 2.5

# Build using "--without tests" to disable tests
%global with_tests       %{?_without_tests:0}%{!?_without_tests:1}

Name:          php-%{composer_vendor}-datafixtures
Version:       %{github_version}
Release:       4%{?dist}
Summary:       Data Fixtures for all Doctrine Object Managers

Group:         Development/Libraries
License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}
Source0:       %{url}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

BuildArch:     noarch
%if %{with_tests}
# For tests
BuildRequires: php(language)                 >= %{php_min_ver}
BuildRequires: php-composer(doctrine/common) >= %{doctrine_min_ver}
BuildRequires: php-composer(doctrine/common) <  %{doctrine_max_ver}
BuildRequires: php-composer(doctrine/orm)    >= %{doctrine_min_ver}
BuildRequires: php-composer(doctrine/orm)    <  %{doctrine_max_ver}
BuildRequires: php-phpunit-PHPUnit
# For tests: phpcompatinfo (computed from v1.0.0)
BuildRequires: php-json
BuildRequires: php-reflection
BuildRequires: php-spl
%endif

Requires:      php(language)                 >= %{php_min_ver}
Requires:      php-composer(doctrine/common) >= %{doctrine_min_ver}
Requires:      php-composer(doctrine/common) <  %{doctrine_max_ver}
# Optional
Requires:      php-composer(doctrine/orm)    >= %{doctrine_min_ver}
Requires:      php-composer(doctrine/orm)    <  %{doctrine_max_ver}
# phpcompatinfo (computed from v1.0.0)
Requires:      php-json
Requires:      php-reflection
Requires:      php-spl

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
This extension aims to provide a simple way to manage and execute the loading
of data fixtures for the Doctrine ORM or ODM.


%prep
%setup -qn %{github_name}-%{github_commit}


%build
# Empty build section, nothing required


%install
mkdir -p %{buildroot}/%{_datadir}/php
cp -rp lib/* %{buildroot}/%{_datadir}/php/


%check
%if %{with_tests}
# Rewrite tests' bootstrap
cat > tests/bootstrap.php <<'BOOTSTRAP'
<?php
spl_autoload_register(function ($class) {
    $src = str_replace('\\', '/', str_replace('_', '/', $class)).'.php';
    @include_once $src;
});
BOOTSTRAP

# Skip tests known to fail
sed -e 's#function test_orderFixturesByDependencies_circularReferencesMakeMethodThrowCircularReferenceException#function SKIP_test_orderFixturesByDependencies_circularReferencesMakeMethodThrowCircularReferenceException#' \
    -e 's#function test_orderFixturesByDependencies_fixturesCantHaveItselfAsParent#function SKIP_test_orderFixturesByDependencies_fixturesCantHaveItselfAsParent#' \
    -e 's#function test_inCaseAFixtureHasAnUnexistentDependencyOrIfItWasntLoaded_throwsException#function SKIP_test_inCaseAFixtureHasAnUnexistentDependencyOrIfItWasntLoaded_throwsException#' \
    -i tests/Doctrine/Tests/Common/DataFixtures/DependentFixtureTest.php
sed 's#function testReferenceReconstruction#function SKIP_testReferenceReconstruction#' \
    -i tests/Doctrine/Tests/Common/DataFixtures/ProxyReferenceRepositoryTest.php

# Create PHPUnit config w/ colors turned off
sed 's/colors="true"/colors="false"/' phpunit.xml.dist > phpunit.xml

%{_bindir}/phpunit --include-path ./lib:./tests -d date.timezone="UTC"
%else
: Tests skipped
%endif


%files
%doc LICENSE *.md UPGRADE composer.json
%{_datadir}/php/Doctrine/Common/DataFixtures


%changelog
* Sat Jun 21 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.0-4
- Added php-composer(%%{composer_vendor}/%%{composer_project}) virtual provide
- Added option to build without tests ("--without tests")
- Updated Doctrine dependencies to use php-composer virtual provides

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Jan 05 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.0.0-2
- Use non-PEAR Doctrine pkgs
- Conditional %%{?dist}

* Fri Dec 20 2013 Shawn Iwinski <shawn.iwinski@gmail.com> 1.0.0-1
- Initial package
